<?php

declare(strict_types=1);

namespace Dedi\SyliusImportExportPlugin\Reader;

use Port\Reader;
use Port\Reader\ReaderFactory;
use SplFileObject;

class TxtReaderFactory implements ReaderFactory
{
    private readonly string $delimiter;

    private readonly bool $trim;

    private readonly string $enclosure;

    private readonly bool $utf8Encode;

    protected ?int $headerRowNumber = null;

    public function __construct(
        string $delimiter = '|',
        string $enclosure = '"',
        bool $trim = true,
        bool $utf8Encode = false,
        ?int $headerRowNumber = null,
    ) {
        $this->delimiter = $delimiter;
        $this->enclosure = $enclosure;
        $this->trim = $trim;
        $this->utf8Encode = $utf8Encode;
        $this->headerRowNumber = $headerRowNumber;
    }

    public function getReader(SplFileObject $file): Reader
    {
        return new TxtReader($file, $this->delimiter, $this->enclosure, $this->trim, $this->utf8Encode, $this->headerRowNumber);
    }
}
